@@ -24,6 +24,8 @@ class KinaseActivity:
     ----------
     evidence : pandas df
         a dataframe that contains (at minimum, but can have more) data columms as evidence to use in analysis and KSTAR_ACCESSION and KSTAR_SITE
+    data_columns: list
+        list of the columns containing the abundance values, which will be used to determine which sites will be used as evidence for activity prediction in each sample
     logger : Logger object
         keeps track of kstar analysis, including any errors that occur
     phospho_type: string, either 'Y' or 'ST'
@@ -36,6 +38,8 @@ class KinaseActivity:
     -------------------
     evidence: pandas dataframe
         inputted evidence column
+    data_columns: list
+        list of columns containing abundance values, which will be used to determine which sites will be used as evidence. If inputted data_columns parameter was None, this lists includes in column in evidence prefixed by 'data:'
     logger : Logger object
         keeps track of kstar analysis, including any errors that occur
     phospho_type: string
@@ -63,18 +67,14 @@ class KinaseActivity:
         median p-values obtained from the activities_list object for each experiment/kinase
     agg_activities: pandas dataframe
     
-    -------------------
-    After Normalization
-    -------------------
-    normalized : bool
-        same as before, but will be set to True
-    random_experiments: 
+    -----------------------------------
+    After Random Enrichment Calculation
+    -----------------------------------
+    random_experiments: pandas dataframe
+        contains information about the sites randomly sampled for each random experiment
     
-    random_kinact:
-    normalized_activities_list:
-    normalized_agg_activities:
-    activities_normalized:
-    fpr_activity:
+    random_kinact: KinaseActivity object
+        KinaseActivity object containing random activities predicted from each of the random experiments
     
     ---------------------------
     After Mann Whitney Analysis
@@ -86,7 +86,7 @@ class KinaseActivity:
         false positive rates for predicted kinase activities
         
     """
-    def __init__(self, evidence, logger, phospho_type = 'Y'):
+    def __init__(self, evidence, logger, data_columns = None, phospho_type = 'Y'):
         
         self.phospho_type = phospho_type
         self.set_evidence(evidence)
@@ -106,21 +106,28 @@ class KinaseActivity:
 
 
         #Properties for normalized information
-        self.normalized = False
+        #self.normalizers = defaultdict()
+        #self.normalized = False
+        #self.normalized_activities_list = None
+        #self.normalized_agg_activities = None
+        #self.activities_normalized = None
+        #self.fpr_activity = None
+        
+        #Location of random experiments
+        self.randomized = False
         self.random_experiments = None
-        self.random_kinact = None
-        self.normalized_activities_list = None
-        self.normalized_agg_activities = None
-        self.activities_normalized = None
-        self.fpr_activity = None
 
 
-        self.aggregate = 'count'
+
+        self.aggregate = 'mean'
         self.threshold = 1.0
         self.greater = True
 
         self.run_date = datetime.now().strftime("%d/%m/%Y %H:%M:%S")
-
+        
+        #if data columns is None, set data columns to be columns with data: in front
+        self.set_data_columns(data_columns = data_columns)
+   
 
     def check_data_columns(self):
         """
@@ -160,15 +167,14 @@ class KinaseActivity:
                     self.data_columns.append(col)  
         else:
             self.data_columns = data_columns
-        self.check_data_columns()      
-    
-    def run_normalization(self, logger, num_random_experiments=150, target_alpha=0.05, PROCESSES = 1):
+        self.check_data_columns()    
+
+    def calculate_random_activities(self, logger, num_random_experiments=150, PROCESSES = 1):
         """
-        Run entire normaliation pipeline 
+        Generate random experiments and calculate the kinase activities for these random experiments
         """
-        self.logger.info("Running Normalization Pipeline")
+        self.logger.info("Running Randomization Pipeline")
         pool = multiprocessing.Pool(processes = PROCESSES)
-        self.normalized = True
         self.num_random_experiments = num_random_experiments
         self.logger.info("Generating random experiments")
         self.random_experiments = generate_random_experiments.build_random_experiments(
@@ -179,41 +185,67 @@ class KinaseActivity:
             self.data_columns,
             pool,
             PROCESSES = PROCESSES)
-
         
         self.logger.info("Calculating random kinase activities")
         self.random_kinact = KinaseActivity(self.random_experiments, logger, phospho_type=self.phospho_type)
         self.random_kinact.add_networks_batch(self.networks)
         self.random_kinact.calculate_kinase_activities( agg='count', threshold=1.0, greater=True, PROCESSES = PROCESSES )
-        
-        self.logger.info("Normalizing Activities")
-        self.normalize(target_alpha=target_alpha)
-
-
-
-    def normalize(self, target_alpha=0.05):
-        """
-        Given random_kinace.activities, summarize, calculate FPR, and normalize. Called in the run_normalization pipelin
-        and useful for changing the target_alpha value, without requiring generation and calculation of random datasets
-        such as in reading a project from slim format.
-
-        Parameters
-        ----------
-        target_alpha: float
-            FPR target value between 0 and 1
-
-
-        """
-        if target_alpha > 1 or target_alpha < 0:
-            self.logger.info("ERROR: Target alpha should be between 0 an 1, setting to default of 0.05")
-            target_alpha = 0.05
-        self.random_kinact.aggregate_activities()
+        self.random_kinact.agg_activities = self.random_kinact.aggregate_activities()
         self.random_kinact.activities = self.random_kinact.summarize_activities()
 
-        self.normalizers, self.fpr_activity = calculate_fpr.generate_fpr_values(self.activities, self.random_kinact.activities, target_alpha)
+    
+    #def run_normalization(self, logger, num_random_experiments=150, target_alpha=0.05, PROCESSES = 1):
+    #    """
+    #    Run entire normaliation pipeline (Generate random experiments, calculate kinase activities for random experiments, and normalize p-values based on provided target_alpha)
+    #    """
+    #    self.logger.info("Running Normalization Pipeline")
+    #    pool = multiprocessing.Pool(processes = PROCESSES)
+    #    self.normalized = True
+    #    self.num_random_experiments = num_random_experiments
+    #    self.logger.info("Generating random experiments")
+    #    self.random_experiments = generate_random_experiments.build_random_experiments(
+    #        self.evidence_binary, 
+    #        config.HUMAN_REF_COMPENDIA, 
+    #        num_random_experiments,
+    #        self.phospho_type, 
+    #        self.data_columns,
+    #        pool,
+    #        PROCESSES = PROCESSES)
 
-        self.normalize_activities(default_normalization=target_alpha)
-        self.activities_normalized = self.summarize_activities(self.normalized_agg_activities,'median_normalized_activity',normalized=True)
+        
+    #    self.logger.info("Calculating random kinase activities")
+    #    self.random_kinact = KinaseActivity(self.random_experiments, logger, phospho_type=self.phospho_type)
+    #    self.random_kinact.add_networks_batch(self.networks)
+    #    self.random_kinact.calculate_kinase_activities( agg='count', threshold=1.0, greater=True, PROCESSES = PROCESSES )
+        
+    #    self.logger.info("Normalizing Activities")
+    #    self.normalize(target_alpha=target_alpha)
+
+
+
+    #def normalize(self, target_alpha=0.05):
+    #    """
+    #    Given random_kinace.activities, summarize, calculate FPR, and normalize. Called in the run_normalization pipelin
+    #    and useful for changing the target_alpha value, without requiring generation and calculation of random datasets
+    #    such as in reading a project from slim format.
+    #
+    #    Parameters
+    #    ----------
+    #    target_alpha: float
+    #        FPR target value between 0 and 1
+    #
+    #
+    #    """
+    #    if target_alpha > 1 or target_alpha < 0:
+    #        self.logger.info("ERROR: Target alpha should be between 0 an 1, setting to default of 0.05")
+    #        target_alpha = 0.05
+    #    self.random_kinact.aggregate_activities()
+    #    self.random_kinact.activities = self.random_kinact.summarize_activities()
+
+    #    self.normalizers, self.fpr_activity = calculate_fpr.generate_fpr_values(self.activities, self.random_kinact.activities, target_alpha)
+
+    #    self.normalize_activities(default_normalization=target_alpha)
+    #    self.activities_normalized = self.summarize_activities(self.normalized_agg_activities,'median_normalized_activity',normalized=True)
         
 
     def add_networks_batch(self,networks):
@@ -264,19 +296,19 @@ class KinaseActivity:
         else:
             self.logger.warning(f"Evidence not set. Evidence columns must include '{config.KSTAR_ACCESSION}' and '{config.KSTAR_SITE}' keys")
     
-    def set_normalizers(self, normalizers):
-        """
-        Sets the Kinase normalization values to be used in calculating the updated p-values
-        Updated p-values normalized via original p-value / normalization-factor * normalization_factor
+    #def set_normalizers(self, normalizers):
+    #    """
+    #    Sets the Kinase normalization values to be used in calculating the updated p-values
+    #    Updated p-values normalized via original p-value / normalization-factor * normalization_factor
 
-        Parameters
-        ----------
-        normalizers : dict or pandas df
-            Kinase Activity Normalizers
-            index : kinase
-            columns : data_column normalization values
-        """
-        self.normalizers = normalizers
+    #    Parameters
+    #    ----------
+    #    normalizers : dict or pandas df
+    #        Kinase Activity Normalizers
+    #        index : kinase
+    #        columns : data_column normalization values
+    #    """
+    #    self.normalizers = normalizers
 
     # def calculate_hypergeometric_single_network(self, evidence, network_id):
     #     """
@@ -367,16 +399,13 @@ class KinaseActivity:
     #     hyp_act['data'] = name
     #     return hyp_act
 
-    def create_binary_evidence(self, data_columns = None, agg = 'count', threshold = 1.0,  greater = True):
+    def create_binary_evidence(self, agg = 'mean', threshold = 1.0,  greater = True):
         """
         Returns a binary evidence data frame according to the parameters passed in for method for aggregating
         duplicates and considering whether a site is included as evidence or not
 
         Parameters
         ----------
-        data_columns : list
-            columns that represent experimental result, if None, takes the columns that start with `data:'' in experiment. 
-            Pass this value in as a list, if seeking to calculate on fewer than all available data columns
         threshold : float
             threshold value used to filter rows 
         agg : {'count', 'mean'}
@@ -412,7 +441,7 @@ class KinaseActivity:
         return evidence_binary
 
 
-    def calculate_kinase_activities(self, data_columns = None, agg = 'count', threshold = 1.0,  greater = True, PROCESSES = 1):
+    def calculate_kinase_activities(self, agg = 'mean', threshold = 1.0,  greater = True, PROCESSES = 1):
         """
         Calculates combined activity of experiments based that uses a threshold value to determine if an experiment sees a site or not
         To use values use 'mean' as agg
@@ -450,9 +479,9 @@ class KinaseActivity:
         self.aggregate = agg
         self.threshold = threshold
         self.greater = greater
-        self.set_data_columns(data_columns)
+        #self.set_data_columns(data_columns)
 
-        self.evidence_binary = self.create_binary_evidence(data_columns = self.data_columns, agg = self.aggregate, threshold = self.threshold,  greater = self.greater)
+        self.evidence_binary = self.create_binary_evidence(agg = self.aggregate, threshold = self.threshold,  greater = self.greater)
         
         # if no data columns are provided use all columns that start with data:
         # data columns that filtered have no evidence are removed
@@ -536,111 +565,113 @@ class KinaseActivity:
             median_activity = ('kinase_activity', 'median'),
         ).reset_index()
         return self.agg_activities
+    
+    #def normalize_activities(self, activities = None, default_normalization = 0.05, normalization_multiplier = 0.05):
+    #    """
+    #    Generates the normalized activities and corresponding summary statistics
 
-    def normalize_activities(self, activities = None, default_normalization = 0.05, normalization_multiplier = 0.05):
-        """
-        Generates the normalized activities and corresponding summary statistics
-
-        Parameters
-        ----------
-        activities : dict
-            hypergeometric activities generated by KSTAR algorithm
-            key : experiment
-            value : hypergeometric result
-        default_normalization: float
-            value to normalize to, if no normalizers are set.
+    #    Parameters
+    #    ----------
+    #    activities : dict
+    #        hypergeometric activities generated by KSTAR algorithm
+    #        key : experiment
+    #        value : hypergeometric result
+    #    default_normalization: float
+    #        value to normalize to, if no normalizers are set.
         
-        Returns
-        --------
-        normalized_activities : dict
-            normalized Kinase Activity results
-            key : experiment
-            value : normalized results
-        summarized_activities : dict
-            summary statistics of normalized kinase activity
-            key : experiment
-            value : summary statistics
-        """
-        self.normalized = True
+    #    Returns
+    #    --------
+    #    normalized_activities : dict
+    #        normalized Kinase Activity results
+    #        key : experiment
+    #        value : normalized results
+    #    summarized_activities : dict
+    #        summary statistics of normalized kinase activity
+    #        key : experiment
+    #        value : summary statistics
+    #    """
+    #    self.normalized = True
+    #    
+    #    if activities is None:
+    #        activities = self.activities_list
+    #    normalized_activities = []
+    #    for data in self.data_columns:
+    #        if type(self.normalizers) is dict:
+    #            normalizers = self.normalizers
+    #        elif type(self.normalizers) is pd.DataFrame and data #in self.normalizers.columns:
+    #            #print("setting normalizers")
+    #            normalizers = self.normalizers[data].to_dict()
+    #        else:
+    #            normalizers = {}
+    #        activity = activities[activities['data'] == data]
+    #        normalized_activities.append(
+    #            self.calculate_normalized_activity(
+    #                activity, 
+    #                normalizers, 
+    #                default_normalization, 
+    #                normalization_multiplier))
+    #    self.normalized_activities_list = pd.concat(normalized_activities)
+    #    self.aggregate_normalized_activities(self.normalized_activities_list)
         
-        if activities is None:
-            activities = self.activities_list
-        normalized_activities = []
-        for data in self.data_columns:
-            if type(self.normalizers) is dict:
-                normalizers = self.normalizers
-            elif type(self.normalizers) is pd.DataFrame and data in self.normalizers.columns:
-                #print("setting normalizers")
-                normalizers = self.normalizers[data].to_dict()
-            else:
-                normalizers = {}
-            activity = activities[activities['data'] == data]
-            normalized_activities.append(
-                self.calculate_normalized_activity(
-                    activity, 
-                    normalizers, 
-                    default_normalization, 
-                    normalization_multiplier))
-        self.normalized_activities_list = pd.concat(normalized_activities)
-        self.aggregate_normalized_activities(self.normalized_activities_list)
+    #    return self.normalized_activities_list, self.normalized_agg_activities
+    
+    
+    #def calculate_normalized_activity(self, kinase_activity, normalizers, default_normalization = 0.05, normalization_multiplier = 0.05):
+    #    """
+    #    Activity is normalized based on kinase normalization factors. 
+    #    Added Columns : 
+    #        Normalization Factor : normalization factor for given Kinase
+    #        Significant : 1 if Kinase Activity <= Normalization Factor
+    #        Normalized Activity : ( Kinase Activity ) / ( Normalization Factor ) * Normalization Multiplier
+
+    #    Parameters
+    #    ----------
+    #    kinase_activity : pandas df
+    #        hypergeometric activity calculated through KSTAR algorithm
+    #    default_normalization : float
+    #        Normalization factor to use if one not provided
+    #    normalization_multiplier : float
+    #        normalization multiplier to use for calculated #normalized kinase activity
+    #    """
+
+    #    normalized_activity = kinase_activity.copy()
+    #    normalized_activity['Normalization Factor'] = normalized_activity[config.KSTAR_KINASE].apply(lambda name: normalizers[name] if name in normalizers.keys() else default_normalization)
+    #    if len(self.networks) > 0:
+    #        normalized_activity['Significant'] = normalized_activity.apply(lambda row: (row['kinase_activity'] <= row['Normalization Factor'] / len( self.networks ) ) * 1, axis = 1)
+    #    else:
+    #        normalized_activity['Significant'] = normalized_activity.apply(lambda row: (row['kinase_activity'] <= row['Normalization Factor']) * 1, axis = 1)
+    #    normalized_activity['Normalized Activity'] = normalized_activity.apply(lambda row: np.clip( row['kinase_activity'] / row['Normalization Factor'] * normalization_multiplier, 0.0, 1.0 ), axis = 1)
+    #    return normalized_activity
+    
+    
+    #def aggregate_normalized_activities(self, normalized_activities):
+    #    """
+    #    Summarizes normalized kinase activity results of all networks by kinase
+    #    Summaries provided : 
+    #        median original activity
+    #        average original activity
+    #        median normalized activity
+    #        average normalized activity
+    #        count significant
+    #        fraction significant
         
-        return self.normalized_activities_list, self.normalized_agg_activities
-
-    def calculate_normalized_activity(self, kinase_activity, normalizers, default_normalization = 0.05, normalization_multiplier = 0.05):
-        """
-        Activity is normalized based on kinase normalization factors. 
-        Added Columns : 
-            Normalization Factor : normalization factor for given Kinase
-            Significant : 1 if Kinase Activity <= Normalization Factor
-            Normalized Activity : ( Kinase Activity ) / ( Normalization Factor ) * Normalization Multiplier
-
-        Parameters
-        ----------
-        kinase_activity : pandas df
-            hypergeometric activity calculated through KSTAR algorithm
-        default_normalization : float
-            Normalization factor to use if one not provided
-        normalization_multiplier : float
-            normalization multiplier to use for calculated normalized kinase activity
-        """
-
-        normalized_activity = kinase_activity.copy()
-        normalized_activity['Normalization Factor'] = normalized_activity[config.KSTAR_KINASE].apply(lambda name: normalizers[name] if name in normalizers.keys() else default_normalization)
-        if len(self.networks) > 0:
-            normalized_activity['Significant'] = normalized_activity.apply(lambda row: (row['kinase_activity'] <= row['Normalization Factor'] / len( self.networks ) ) * 1, axis = 1)
-        else:
-            normalized_activity['Significant'] = normalized_activity.apply(lambda row: (row['kinase_activity'] <= row['Normalization Factor']) * 1, axis = 1)
-        normalized_activity['Normalized Activity'] = normalized_activity.apply(lambda row: np.clip( row['kinase_activity'] / row['Normalization Factor'] * normalization_multiplier, 0.0, 1.0 ), axis = 1)
-        return normalized_activity
-
-    def aggregate_normalized_activities(self, normalized_activities):
-        """
-        Summarizes normalized kinase activity results of all networks by kinase
-        Summaries provided : 
-            median original activity
-            average original activity
-            median normalized activity
-            average normalized activity
-            count significant
-            fraction significant
+    #    Parameters
+    #    ----------
+    #    normalized_activity : pandas df
+    #        Normalized kinase activty
         
-        Parameters
-        ----------
-        normalized_activity : pandas df
-            Normalized kinase activty
-        
-        Returns
-        --------
-        summary : pandas df
-            summarized data of all networks by kinase
-        """
-        self.normalized_agg_activities = normalized_activities.groupby(['data',config.KSTAR_KINASE]).agg(
-            median_original_activity = ('kinase_activity', 'median'),
-            median_normalized_activity = ('Normalized Activity', 'median'),
-            count_significant = ('Significant', 'sum'),
-            fraction_significant = ('Significant', 'mean')
-        ).reset_index()
-        return self.normalized_agg_activities
+    #    Returns
+    #    --------
+    #    summary : pandas df
+    #        summarized data of all networks by kinase
+    #    """
+    #    self.normalized_agg_activities = normalized_activities.groupby(['data',config.KSTAR_KINASE]).agg(
+    #        median_original_activity = ('kinase_activity', 'median'),
+    #        median_normalized_activity = ('Normalized Activity', 'median'),
+    #        count_significant = ('Significant', 'sum'),
+    #        fraction_significant = ('Significant', 'mean')
+    #    ).reset_index()
+    #    return self.normalized_agg_activities
 
     def  find_pvalue_limits(self, data_columns, agg = 'count', threshold = 1.0):
         """
@@ -752,8 +783,8 @@ class KinaseActivity:
             log.info("Warning: number of trials for Mann Whitney exceeds number available, using %d instead of %d"%(self.num_random_experiments, number_sig_trials))
             number_sig_trials = self.num_random_experiments
 
-        self.activities_mann_whitney = pd.DataFrame(index=self.activities_normalized.index, columns=self.activities_normalized.columns)
-        self.fpr_mann_whitney = pd.DataFrame(index=self.activities_normalized.index, columns=self.activities_normalized.columns)
+        self.activities_mann_whitney = pd.DataFrame(index=self.activities.index, columns=self.activities.columns)
+        self.fpr_mann_whitney = pd.DataFrame(index=self.activities.index, columns=self.activities.columns)
         #for every kinase and every dataset, calculate and assemble dataframes of activities and significance values
 
         for exp in self.data_columns:
@@ -766,16 +797,13 @@ class KinaseActivity:
             pval_arr = []
             fpr_arr = []
             with concurrent.futures.ProcessPoolExecutor(max_workers=PROCESSES) as executor:
-                for pval, fpr in executor.map(calculate_MannWhitney_one_experiment_one_kinase, repeat(activities_sub), repeat(rand_activities_sub), repeat(self.num_networks), self.activities_normalized.index, repeat(exp), repeat(number_sig_trials)):
+                for pval, fpr in executor.map(calculate_MannWhitney_one_experiment_one_kinase, repeat(activities_sub), repeat(rand_activities_sub), repeat(self.num_networks), self.activities.index, repeat(exp), repeat(number_sig_trials)):
                     pval_arr.append(pval)
                     fpr_arr.append(fpr)
-                #print(pval_arr)
+
             self.activities_mann_whitney[exp] = pval_arr
             self.fpr_mann_whitney[exp] = fpr_arr
-            #for kinase in self.normalized_summary.index:
-            #    log.info("\tKinase: %s"%(kinase))
-            #    self.activities_mann_whitney.at[kinase, exp], self.significance_mann_whitney.at[kinase, exp] = calculate_MannWhitney_one_experiment_one_kinase(
-            #        activities_sub, rand_activities_sub, len(self.networks), kinase, exp, number_sig_trials, target_alpha=target_alpha)      
+    
 
 
 
@@ -964,10 +992,11 @@ def calculate_MannWhitney_one_experiment_one_kinase(kinact_activities, rand_acti
 Methods for running KSTAR pipeline
 ****************************************
 """
-def run_kstar_analysis(experiment, log, networks, phospho_types =['Y', 'ST'], data_columns = None, agg = 'count', threshold = 1.0,  greater = True, PROCESSES = 1):
+def enrichment_analysis(experiment, log, networks, phospho_types =['Y', 'ST'], data_columns = None, agg = 'mean', threshold = 1.0,  greater = True, PROCESSES = 1):
     """
-    A super method to establish a kstar KinaseActivity object from an experiment with an activity log
-    add the networks, calculate, aggregate, and summarize the activities into a final activity object
+    Function to establish a kstar KinaseActivity object from an experiment with an activity log
+    add the networks, calculate, aggregate, and summarize the hypergeometric enrichment into a final activity object. Should be followed by 
+    randomized_analyis, then Mann_Whitney_analysis.
 
     Parameters
     ----------
@@ -1024,21 +1053,46 @@ def run_kstar_analysis(experiment, log, networks, phospho_types =['Y', 'ST'], da
         else:
             print("ERROR: Did not recognize phosphoType %s, which should only include 'Y' or 'ST' "%(phospho_type))
             return
-        kinact = KinaseActivity(experiment_sub, log, phospho_type=phospho_type)
+        kinact = KinaseActivity(experiment_sub, log, data_columns = data_columns, phospho_type=phospho_type)
         kinact.add_networks_batch(networks[phospho_type])
-        kinact.calculate_kinase_activities(data_columns, agg=agg, threshold=threshold, greater=greater, PROCESSES = PROCESSES)
+        kinact.calculate_kinase_activities(agg=agg, threshold=threshold, greater=greater, PROCESSES = PROCESSES)
         kinact.aggregate_activities()
         kinact.activities = kinact.summarize_activities()
         kinact_dict[phospho_type] = kinact
     return kinact_dict
 
-def normalize_analysis(kinact_dict, log, num_random_experiments=150, target_alpha = 0.05, PROCESSES = 1):
+#def normalize_analysis(kinact_dict, log, num_random_experiments=150, target_alpha = 0.05, PROCESSES = 1):
+#    """
+#    Creates random experiments, drawn from the human phosphoproteome, according to the distribution of the number of compendia
+#    that each data column in the experiment has for num_random_experiments. Kinase activity calculation is then run on every random experiment
+#    and then assembled for each data column to calculate the pvalue at which a kinase hits the target_alpha value of false positives. 
+#    Finally, it takes these empirically defined pvalue corrections and normalizes the kinase activities according to these, such that
+#    the real experimental data also has the target_alpha value. 
+#
+#    Parameters
+#    ----------
+#    kinact_dict: KinaseActivities dictionary
+#        Has keys ['Y'] and/or ['ST'] and values that are KinaseActivity objects. These objects are modified to add normalization
+#    log: logger 
+#        Logger for logging activity messages
+#    num_random_experiments: int
+#        Number of random experiments, for each data column, to create and run activity from
+#    target_alpha: float 
+#        Value between 0 and 1 that is the target false positive rate. 
+#
+#
+#    """
+#
+#    if target_alpha > 1 or target_alpha < 0: 
+#        raise ValueError('ERROR: target_alpha must be value between 0 and 1')
+#
+#    for phospho_type, kinact in kinact_dict.items():
+#        kinact.run_normalization(log, num_random_experiments, target_alpha, PROCESSES = PROCESSES)
+        
+def randomized_analysis(kinact_dict, log, num_random_experiments=150, PROCESSES = 1):
     """
     Creates random experiments, drawn from the human phosphoproteome, according to the distribution of the number of compendia
-    that each data column in the experiment has for num_random_experiments. Kinase activity calculation is then run on every random experiment
-    and then assembled for each data column to calculate the pvalue at which a kinase hits the target_alpha value of false positives. 
-    Finally, it takes these empirically defined pvalue corrections and normalizes the kinase activities according to these, such that
-    the real experimental data also has the target_alpha value. 
+    that each data column in the experiment has for num_random_experiments. Kinase activity calculation is then run on every random experiment. 
 
     Parameters
     ----------
@@ -1048,17 +1102,10 @@ def normalize_analysis(kinact_dict, log, num_random_experiments=150, target_alph
         Logger for logging activity messages
     num_random_experiments: int
         Number of random experiments, for each data column, to create and run activity from
-    target_alpha: float 
-        Value between 0 and 1 that is the target false positive rate. 
-
-
     """
 
-    if target_alpha > 1 or target_alpha < 0: 
-        raise ValueError('ERROR: target_alpha must be value between 0 and 1')
-
     for phospho_type, kinact in kinact_dict.items():
-        kinact.run_normalization(log, num_random_experiments, target_alpha, PROCESSES = PROCESSES)
+        kinact.calculate_random_activities(log, num_random_experiments, PROCESSES = PROCESSES)
         
 def Mann_Whitney_analysis(kinact_dict, log, number_sig_trials = 100, PROCESSES = 1):
     """
@@ -1079,6 +1126,9 @@ def Mann_Whitney_analysis(kinact_dict, log, number_sig_trials = 100, PROCESSES =
 
     for phospho_type, kinact in kinact_dict.items():
         kinact.calculate_Mann_Whitney_activities_sig(log, number_sig_trials = number_sig_trials, PROCESSES = PROCESSES)
+        
+    
+        
     
 def save_kstar(kinact_dict, name, odir, PICKLE=True):
         """
@@ -1116,20 +1166,21 @@ def save_kstar(kinact_dict, name, odir, PICKLE=True):
             kinact.agg_activities.to_csv(f"{odir}/RESULTS/{name_out}_aggregated_activities.tsv", sep = '\t', index = False)
             kinact.activities.to_csv(f"{odir}/RESULTS/{name_out}_activities.tsv", sep = '\t', index = True)
             kinact.evidence_binary.to_csv(f"{odir}/RESULTS/{name_out}_binarized_experiment.tsv", sep='\t', index=False)
-
-            if kinact.normalized:
-
+            
+            if hasattr(kinact, 'random_kinact'):
                 kinact.random_kinact.activities_list.to_csv(f"{odir}/RESULTS/{name_out}_random_activities_list.tsv", sep = '\t')
                 kinact.random_kinact.agg_activities.to_csv(f"{odir}/RESULTS/{name_out}_random_aggregated_activities.tsv", sep = '\t', index = False)
                 kinact.random_kinact.activities.to_csv(f"{odir}/RESULTS/{name_out}_random_activities.tsv", sep = '\t', index = True)
-
-                kinact.normalized_activities_list.to_csv(f"{odir}/RESULTS/{name_out}_normalized_activities_list.tsv", sep = '\t', index = True)
-                kinact.normalized_agg_activities.to_csv(f"{odir}/RESULTS/{name_out}_normalized_aggregated_activities.tsv", sep = '\t', index = True)
-                kinact.activities_normalized.to_csv(f"{odir}/RESULTS/{name_out}_activities_normalized.tsv", sep = '\t', index = True)
-
                 kinact.random_experiments.to_csv(f"{odir}/RESULTS/{name_out}_random_experiments.tsv", sep = '\t', index = False)
-                kinact.fpr_activity.to_csv(f"{odir}/RESULTS/{name_out}_activities_fpr.tsv", sep='\t', index=True)
                 kinact.random_kinact.evidence.to_csv(f"{odir}/RESULTS/{name_out}_random_experiments.tsv", sep = '\t', index = False)
+                
+            #if kinact.normalized:
+
+            #    kinact.normalized_activities_list.to_csv(f"{odir}/RESULTS/{name_out}_normalized_activities_list.tsv", sep = '\t', index = True)
+            #    kinact.normalized_agg_activities.to_csv(f"{odir}/RESULTS/{name_out}_normalized_aggregated_activities.tsv", sep = '\t', index = True)
+            #    kinact.activities_normalized.to_csv(f"{odir}/RESULTS/{name_out}_activities_normalized.tsv", sep = '\t', index = True)
+            #    kinact.fpr_activity.to_csv(f"{odir}/RESULTS/{name_out}_activities_fpr.tsv", sep='\t', index=True)
+
 
             if hasattr(kinact, 'activities_mann_whitney'):
                 kinact.activities_mann_whitney.to_csv(f"{odir}/RESULTS/{name_out}_mann_whitney_activities.tsv", sep='\t', index = True) 
@@ -1182,7 +1233,7 @@ def save_kstar_slim(kinact_dict, name, odir):
         param_temp['threshold'] = kinact.threshold
         param_temp['run_date']= kinact.run_date
         param_temp['mann_whitney'] = False
-        param_temp['normalized'] = False
+        param_temp['randomized'] = False
         param_temp['num_networks'] = kinact.num_networks
         param_temp['network_directory'] = kinact.network_directory
 
@@ -1191,12 +1242,15 @@ def save_kstar_slim(kinact_dict, name, odir):
         kinact.activities.to_csv(f"{odir}/RESULTS/{name_out}_activities.tsv", sep = '\t', index = True)
         kinact.evidence_binary.to_csv(f"{odir}/RESULTS/{name_out}_binarized_experiment.tsv", sep='\t', index=False)
 
-        if kinact.normalized:
-            param_temp['normalized'] = True
+        #if kinact.normalized:
+        #    param_temp['normalized'] = True
+        #    kinact.activities_normalized.to_csv(f"{odir}/RESULTS/{name_out}_activities_normalized.tsv", sep = '\t', index = True)
+        #    kinact.fpr_activity.to_csv(f"{odir}/RESULTS/{name_out}_activities_fpr.tsv", sep='\t', index=True)
+            
+        if hasattr(kinact, 'random_kinact'):
+            param_temp['randomized'] = True
             param_temp['num_random_experiments'] = kinact.num_random_experiments
             kinact.random_kinact.activities_list.to_csv(f"{odir}/RESULTS/{name_out}_random_activities_list.tsv", sep = '\t')
-            kinact.activities_normalized.to_csv(f"{odir}/RESULTS/{name_out}_activities_normalized.tsv", sep = '\t', index = True)
-            kinact.fpr_activity.to_csv(f"{odir}/RESULTS/{name_out}_activities_fpr.tsv", sep='\t', index=True)
             kinact.random_kinact.evidence.to_csv(f"{odir}/RESULTS/{name_out}_random_experiments.tsv", sep = '\t', index = False)
 
         if hasattr(kinact, 'activities_mann_whitney'):
@@ -1253,13 +1307,16 @@ def from_kstar_slim(name, odir, log):
             kinact.activities_mann_whitney = pd.read_csv(f"{odir}/RESULTS/{name_out}_mann_whitney_activities.tsv", sep='\t', index_col = config.KSTAR_KINASE) 
             kinact.fpr_mann_whitney = pd.read_csv(f"{odir}/RESULTS/{name_out}_mann_whitney_fpr.tsv", sep='\t', index_col = config.KSTAR_KINASE) 
             params.pop('mann_whitney', None)
-        if params['normalized']:
+            
+        #if params['normalized']:
+        #    kinact.activities_normalized= pd.read_csv(f"{odir}/RESULTS/{name_out}_activities_normalized.tsv", sep = '\t', index_col = config.KSTAR_KINASE)
+        #    kinact.fpr_activity = pd.read_csv(f"{odir}/RESULTS/{name_out}_activities_fpr.tsv", sep='\t', index_col=config.KSTAR_KINASE)
+        
+        if params['randomized']:
             rand_experiments = pd.read_csv(f"{odir}/RESULTS/{name_out}_random_experiments.tsv", sep = '\t')
 
             kinact.random_kinact = KinaseActivity(rand_experiments, log, phospho_type=phospho_type)
             kinact.random_kinact.activities_list = pd.read_csv(f"{odir}/RESULTS/{name_out}_random_activities_list.tsv", sep = '\t')
-            kinact.activities_normalized= pd.read_csv(f"{odir}/RESULTS/{name_out}_activities_normalized.tsv", sep = '\t', index_col = config.KSTAR_KINASE)
-            kinact.fpr_activity = pd.read_csv(f"{odir}/RESULTS/{name_out}_activities_fpr.tsv", sep='\t', index_col=config.KSTAR_KINASE)
             kinact.random_kinact.evidence = pd.read_csv(f"{odir}/RESULTS/{name_out}_random_experiments.tsv", sep = '\t')
             #set data columns according to file
             kinact.random_kinact.set_data_columns(data_columns=None)
@@ -1308,7 +1365,6 @@ def from_kstar_nextflow(name, odir, log = None):
             #rand_experiments = pd.read_csv(f"{odir}/{phospho_type}/{name_out}_random_experiments.tsv", sep = '\t')
             #kinact.random_kinact = KinaseActivity(rand_experiments, log, phospho_type=phospho_type)
             #kinact.random_kinact.activities_list = pd.read_csv(f"{odir}/{phospho_type}/{name}_random_activities_list.tsv", sep = '\t', index_col=0)
-            kinact.activities_normalized= pd.read_csv(f"{odir}/{phospho_type}/normalized_activity/{name}_normalized_activities.tsv", sep = '\t', index_col = config.KSTAR_KINASE)
             #kinact.random_kinact.evidence = pd.read_csv(f"{odir}/{phospho_type}/{name_out}_random_experiments.tsv", sep = '\t')
             #set data columns according to file
             #kinact.random_kinact.set_data_columns(data_columns=None)
